@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '1.007';
+our $VERSION = '1.008';
 
 sub new {
 	my ($class) = @_;
@@ -1012,7 +1012,8 @@ sub PT::CalcOperands::X {
     return (       $class->{RealNumber}
                 || $class->{ScalarVariable}
                 || $class->{ArrayElement}
-                || $class->{HashElement} )->X($className);
+                || $class->{HashElement}
+			 	|| $class->{ClassAccessor} )->X($className);
 }
 
 sub PT::CalcOperator::X {
@@ -1260,7 +1261,7 @@ my $parser = qr {
 
     <objrule:  PT::Calc>                       <CalcExpression>
     <objrule:  PT::CalcExpression>             <[CalcOperands]>+ % <[CalcOperator]>
-    <objrule:  PT::CalcOperands>               <RealNumber> | <ScalarVariable> | <ArrayElement> | <HashElement>
+    <objrule:  PT::CalcOperands>               <RealNumber> | <ScalarVariable> | <ArrayElement> | <HashElement> | <ClassAccessor>
     <objtoken: PT::CalcOperator>               <Plus> | <Minus> | <Multiply> | <Divide>
 
     <objrule:  PT::Return>                     <TokenReturn> <RHS>? <SemiColon>
@@ -1363,11 +1364,9 @@ HL is a programming language.
 			var number = {};
 
 			if(class.counter < 10) {
-				var counter = class.counter;
-				counter = counter + 1;
-				class.counter = counter;
+				class.counter = class.counter + 1;
 
-				number = {"number" : class.returnNumber()};
+				number = { "number" : class.returnNumber() };
 				return number;
 			}
 
